Stone Soup Framework
====================

.. automodule:: stonesoup

Components
----------
Stone Soup has a number of components which are used to build up a tracker.
These included components are built upon the base :doc:`interface`.

Enabling Components
^^^^^^^^^^^^^^^^^^^
.. toctree::

    stonesoup.detector
    stonesoup.feeder
    stonesoup.metricgenerator
    stonesoup.reader
    stonesoup.simulator
    stonesoup.smoother
    stonesoup.tracker
    stonesoup.writer
    stonesoup.platform
    stonesoup.sensor

Tracker Components
^^^^^^^^^^^^^^^^^^
.. toctree::

    stonesoup.dataassociator
    stonesoup.deleter
    stonesoup.hypothesiser
    stonesoup.initiator
    stonesoup.mixturereducer
    stonesoup.models
    stonesoup.predictor
    stonesoup.resampler
    stonesoup.updater

Data Types
----------
Stone Soup has a number of data types used to pass data between components.
These are built upon the :doc:`types`.

.. toctree::

    stonesoup.types


